==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetGenericQueries.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetGenericQueries]
(
	@VCC								VARCHAR(50) = NULL,
	@SearchCriteria						VARCHAR(50) = NULL,
	@SearchExpression					VARCHAR(50) = NULL,
	@StartDate							DATETIME,
	@EndDate							DATETIME
)
AS
BEGIN

	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT
		[VCC]							''vcc'',
		[Name]							''name'',
		[Description]					''description'',
		[Query]							''query'',
		[RawData]						''rawData'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId''
	FROM
		[dbo].[GenericQuery] (NOLOCK)
	WHERE
		[VCC] = ''' + @VCC + '''
		AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Query], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''query'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'
	
	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			--AND CONVERT(VARCHAR(10), [CreatedDate], 120) BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
	ORDER BY [CreatedDate] DESC
	'
	SET NOCOUNT OFF
	
	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.18.0_database.tar.gz: database/mssql/procedures/GetGenericQueries.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetGenericQueries]
(
	@VCC								VARCHAR(50) = NULL,
	@SearchCriteria						VARCHAR(50) = NULL,
	@SearchExpression					VARCHAR(50) = NULL,
	@StartDate							DATETIME,
	@EndDate							DATETIME
)
AS
BEGIN

	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
	SET NOCOUNT ON

	SELECT
		[VCC]							''vcc'',
		[Name]							''name'',
		[Description]					''description'',
		[Query]							''query'',
		[RawData]						''rawData'',
		[CreatedDate]					''createdDate'',
		[CreatedByUserId]				''createdByUserId'',
		[LastModifiedDate]				''lastModifiedDate'',
		[LastModifiedByUserId]			''lastModifiedByUserId'',
		[Version]                       ''version''
	FROM
		[dbo].[GenericQuery] (NOLOCK)
	WHERE
		[VCC] = ''' + @VCC + '''
		AND ISNULL([Name], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''name'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Description], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''description'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END
		AND ISNULL([Query], '''') LIKE CASE WHEN ''' + @SearchCriteria + ''' = ''query'' THEN ''%' + @SearchExpression + '%'' ELSE ''%'' END'
	
	IF(@StartDate IS NOT NULL AND @EndDate IS NOT NULL)
	BEGIN
		SET @SQL += '
			--AND CONVERT(VARCHAR(10), [CreatedDate], 120) BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
			AND [CreatedDate] BETWEEN ''' + CONVERT(VARCHAR(10), @StartDate, 120) + ''' AND ''' + CONVERT(VARCHAR(10), @EndDate, 120) + '''
		'
	END
	SET @SQL += '
	ORDER BY [CreatedDate] DESC
	'
	SET NOCOUNT OFF
	
	EXEC(@SQL)
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
